@@ -115,6 +115,8 @@ class GenMarker {
 
   uint64_t getGenomicPosition();
   uint32_t getChromosomeIndex();
+  std::string getNCBIChromosomeName();
+  std::string getUCSCChromosomeName();
 };
 
 GenMatrix::~GenMatrix() {
@@ -455,6 +457,67 @@ uint32_t GenMarker::getChromosomeIndex() {
   }
 }
 
+std::string GenMarker::getNCBIChromosomeName() {
+  uint32_t n = static_cast<uint32_t>(atoi(sChrom.c_str()));
+  std::string ret;
+  switch( n ) {
+  case 0:
+    if ( sChrom.compare("X") == 0 ) {
+      return std::string("X");
+    }
+    else if ( sChrom.compare("Y") == 0 ) {
+      return std::string("Y");
+    }
+    else if ( sChrom.compare("XY") == 0 ) {
+      return std::string("XY");
+    }
+    else if ( sChrom.compare("MT") == 0 ) {
+      return std::string("MT");
+    }
+    else {
+      Logger::gLogger->error("GenMarker::getNCBIChromosomeName() - Cannot recognize chromosome %s", sChrom.c_str());
+      return std::string("");
+    }
+  case 1:
+  case 2:
+  case 3:
+  case 4:
+  case 5:
+  case 6:
+  case 7:
+  case 8:
+  case 9:
+  case 10:
+  case 11:
+  case 12:
+  case 13:
+  case 14:
+  case 15:
+  case 16:
+  case 17:
+  case 18:
+  case 19:
+  case 20:
+  case 21:
+  case 22:
+    return sChrom;
+  case 23:
+    return std::string("X");
+  case 24:
+    return std::string("Y");
+  case 25:
+    return std::string("XY");
+  case 26:
+   return std::string("MT");
+  default:
+    Logger::gLogger->error("GenMarker::getNCBIChromosomeName() - Cannot recognize chromosome %s", sChrom.c_str());
+    return std::string("");
+  }
+}
+
+std::string GenMarker::getUCSCChromosomeName() {
+  return (std::string("chr")+getNCBIChromosomeName());
+}
 
 // open BED files without reading actual genotypes
 void VcfMatrix::open(const char* vcfFile)
